<?php
/**
 * Plugin Name: AlertyFast
 * Description: Send WhatsApp notifications for WooCommerce events using AlertyFast API
 * Version: 1.0.0
 * Author: AlertyFast
 * Text Domain: alertyfast
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Define plugin constants
define('ALERTYFAST_VERSION', '1.0.0');
define('ALERTYFAST_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('ALERTYFAST_PLUGIN_URL', plugin_dir_url(__FILE__));

// Include required files
require_once ALERTYFAST_PLUGIN_DIR . 'includes/class-alertyfast-settings.php';
require_once ALERTYFAST_PLUGIN_DIR . 'includes/class-alertyfast-api.php';
require_once ALERTYFAST_PLUGIN_DIR . 'includes/class-alertyfast-woocommerce.php';

// Hook for plugin activation
register_activation_hook(__FILE__, 'alertyfast_activate');

/**
 * Plugin activation function
 */
function alertyfast_activate() {
    // Initialize default settings
    $default_settings = array(
        'api_key' => '',
        'new_order_notifications' => 'no',
        'new_order_phone' => '',
        'paid_order_notifications' => 'no',
        'paid_order_phone' => ''
    );
    
    update_option('alertyfast_settings', $default_settings);
}

/**
 * Initialize the plugin
 */
function alertyfast_init() {
    // Load text domain for translations
    load_plugin_textdomain('alertyfast', false, dirname(plugin_basename(__FILE__)) . '/languages');
    
    // Initialize WooCommerce integration
    new AlertyFast_WooCommerce();
}
add_action('plugins_loaded', 'alertyfast_init');

/**
 * Add admin menu item
 */
function alertyfast_add_admin_menu() {
    add_menu_page(
        __('AlertyFast Settings', 'alertyfast'),
        __('AlertyFast', 'alertyfast'),
        'manage_options',
        'alertyfast',
        'alertyfast_settings_page',
        'dashicons-format-chat',
        100
    );
}
add_action('admin_menu', 'alertyfast_add_admin_menu');

/**
 * Register settings
 */
function alertyfast_register_settings() {
    register_setting(
        'alertyfast_settings_group',
        'alertyfast_settings',
        array(
            'sanitize_callback' => 'alertyfast_validate_settings'
        )
    );
}
add_action('admin_init', 'alertyfast_register_settings');

/**
 * AJAX handler for testing API connection
 */
function alertyfast_ajax_test_connection() {
    // Check nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'alertyfast_test_connection')) {
        wp_send_json_error(__('Security check failed.', 'alertyfast'));
        return;
    }
    
    // Check if user has permission
    if (!current_user_can('manage_options')) {
        wp_send_json_error(__('You do not have permission to perform this action.', 'alertyfast'));
        return;
    }
    
    // Check required data
    if (empty($_POST['api_key']) || empty($_POST['phone_number'])) {
        wp_send_json_error(__('API key and phone number are required.', 'alertyfast'));
        return;
    }
    
    $api_key = sanitize_text_field($_POST['api_key']);
    $phone_number = sanitize_text_field($_POST['phone_number']);
    
    // Initialize API with temporary API key
    $api = new AlertyFast_API();
    
    // Update API key temporarily
    $reflection = new ReflectionClass($api);
    $property = $reflection->getProperty('api_key');
    $property->setAccessible(true);
    $property->setValue($api, $api_key);
    
    // Send test message
    $result = $api->test_connection($phone_number);
    
    if (is_wp_error($result)) {
        wp_send_json_error($result->get_error_message());
        return;
    }
    
    wp_send_json_success();
}
add_action('wp_ajax_alertyfast_test_connection', 'alertyfast_ajax_test_connection');

/**
 * Validate settings before saving
 * 
 * @param array $input The settings input
 * @return array The validated settings
 */
function alertyfast_validate_settings($input) {
    $output = array();
    
    // Validate API key
    $output['api_key'] = sanitize_text_field($input['api_key']);
    
    // Validate notification settings
    $output['new_order_notifications'] = isset($input['new_order_notifications']) && $input['new_order_notifications'] === 'yes' ? 'yes' : 'no';
    $output['paid_order_notifications'] = isset($input['paid_order_notifications']) && $input['paid_order_notifications'] === 'yes' ? 'yes' : 'no';
    
    // Validate phone numbers
    if ($output['new_order_notifications'] === 'yes' && empty($input['new_order_phone'])) {
        add_settings_error(
            'alertyfast_settings',
            'new_order_phone',
            __('WhatsApp number for new orders is required when notifications are enabled.', 'alertyfast'),
            'error'
        );
    }
    
    if ($output['paid_order_notifications'] === 'yes' && empty($input['paid_order_phone'])) {
        add_settings_error(
            'alertyfast_settings',
            'paid_order_phone',
            __('WhatsApp number for paid orders is required when notifications are enabled.', 'alertyfast'),
            'error'
        );
    }
    
    $output['new_order_phone'] = sanitize_text_field($input['new_order_phone']);
    $output['paid_order_phone'] = sanitize_text_field($input['paid_order_phone']);
    
    return $output;
}

/**
 * Settings page content
 */
function alertyfast_settings_page() {
    // Get saved settings
    $settings = get_option('alertyfast_settings');
    ?>
    <div class="wrap">
        <h1><?php echo esc_html__('AlertyFast Settings', 'alertyfast'); ?></h1>
        
        <?php
        // Show settings errors if any
        settings_errors('alertyfast_settings');
        
        // Check for settings update
        if (isset($_GET['settings-updated']) && $_GET['settings-updated'] === 'true' && !count(get_settings_errors('alertyfast_settings'))) {
            echo '<div class="notice notice-success is-dismissible"><p>' . esc_html__('Settings saved successfully!', 'alertyfast') . '</p></div>';
        }
        ?>
        
        <div class="nav-tab-wrapper">
            <a href="#settings" class="nav-tab nav-tab-active"><?php echo esc_html__('Settings', 'alertyfast'); ?></a>
            <a href="#help" class="nav-tab"><?php echo esc_html__('Help', 'alertyfast'); ?></a>
        </div>
        
        <div id="settings-tab" class="tab-content" style="display: block;">
            <form method="post" action="options.php">
                <?php
                settings_fields('alertyfast_settings_group');
                do_settings_sections('alertyfast_settings_group');
                ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php echo esc_html__('API Key', 'alertyfast'); ?></th>
                        <td>
                            <input type="text" name="alertyfast_settings[api_key]" id="alertyfast_api_key" value="<?php echo esc_attr($settings['api_key'] ?? ''); ?>" class="regular-text" />
                            <p class="description"><?php echo esc_html__('Enter your AlertyFast API key', 'alertyfast'); ?></p>
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php echo esc_html__('Test Connection', 'alertyfast'); ?></th>
                        <td>
                            <input type="text" id="alertyfast_test_phone" placeholder="<?php echo esc_attr__('Enter a WhatsApp number', 'alertyfast'); ?>" class="regular-text" />
                            <button type="button" id="alertyfast_test_connection" class="button button-secondary">
                                <?php echo esc_html__('Send Test Message', 'alertyfast'); ?>
                            </button>
                            <span id="alertyfast_test_result"></span>
                            <p class="description"><?php echo esc_html__('Send a test message to verify your API key works correctly.', 'alertyfast'); ?></p>
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php echo esc_html__('New Order Notifications', 'alertyfast'); ?></th>
                        <td>
                            <label>
                                <input type="checkbox" name="alertyfast_settings[new_order_notifications]" value="yes" <?php checked(($settings['new_order_notifications'] ?? 'no'), 'yes'); ?> />
                                <?php echo esc_html__('Enable notifications for new orders', 'alertyfast'); ?>
                            </label>
                        </td>
                    </tr>
                    
                    <tr valign="top" class="new-order-phone-field" <?php if (($settings['new_order_notifications'] ?? 'no') !== 'yes') echo 'style="display:none;"'; ?>>
                        <th scope="row"><?php echo esc_html__('WhatsApp Number for New Orders', 'alertyfast'); ?></th>
                        <td>
                            <input type="text" name="alertyfast_settings[new_order_phone]" value="<?php echo esc_attr($settings['new_order_phone'] ?? ''); ?>" class="regular-text" />
                            <p class="description"><?php echo esc_html__('Enter the WhatsApp number to receive new order notifications', 'alertyfast'); ?></p>
                        </td>
                    </tr>
                    
                    <tr valign="top">
                        <th scope="row"><?php echo esc_html__('Paid Order Notifications', 'alertyfast'); ?></th>
                        <td>
                            <label>
                                <input type="checkbox" name="alertyfast_settings[paid_order_notifications]" value="yes" <?php checked(($settings['paid_order_notifications'] ?? 'no'), 'yes'); ?> />
                                <?php echo esc_html__('Enable notifications for paid orders', 'alertyfast'); ?>
                            </label>
                        </td>
                    </tr>
                    
                    <tr valign="top" class="paid-order-phone-field" <?php if (($settings['paid_order_notifications'] ?? 'no') !== 'yes') echo 'style="display:none;"'; ?>>
                        <th scope="row"><?php echo esc_html__('WhatsApp Number for Paid Orders', 'alertyfast'); ?></th>
                        <td>
                            <input type="text" name="alertyfast_settings[paid_order_phone]" value="<?php echo esc_attr($settings['paid_order_phone'] ?? ''); ?>" class="regular-text" />
                            <p class="description"><?php echo esc_html__('Enter the WhatsApp number to receive paid order notifications', 'alertyfast'); ?></p>
                        </td>
                    </tr>
                </table>
                
                <?php submit_button(); ?>
            </form>
        </div>
        
        <div id="help-tab" class="tab-content" style="display: none;">
            <h2><?php echo esc_html__('How to Use AlertyFast for WooCommerce', 'alertyfast'); ?></h2>
            
            <h3><?php echo esc_html__('Getting Started', 'alertyfast'); ?></h3>
            <ol>
                <li><?php echo esc_html__('Sign up for an account at', 'alertyfast'); ?> <a href="https://alertyfast.com" target="_blank">AlertyFast.com</a></li>
                <li><?php echo esc_html__('Get your API key from the AlertyFast dashboard', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Enter your API key in the settings tab', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Test your connection to make sure it works', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Enable the notifications you want to receive', 'alertyfast'); ?></li>
            </ol>
            
            <h3><?php echo esc_html__('Message Format Examples', 'alertyfast'); ?></h3>
            
            <h4><?php echo esc_html__('New Order Notification', 'alertyfast'); ?></h4>
            <div style="background-color: #f9f9f9; padding: 15px; border-left: 4px solid #2196F3;">
<pre>
🛒 *New Order #123*

Customer: John Doe
Total: $50.00
Items: 2

*Order Items:*
• T-shirt x1 - $25.00
• Mug x1 - $25.00

View Order: https://yoursite.com/wp-admin/post.php?post=123&action=edit
</pre>
            </div>
            
            <h4><?php echo esc_html__('Paid Order Notification', 'alertyfast'); ?></h4>
            <div style="background-color: #f9f9f9; padding: 15px; border-left: 4px solid #4CAF50;">
<pre>
💰 *Order #123 Paid*

Customer: John Doe
Total: $50.00
Payment Method: Credit Card

View Order: https://yoursite.com/wp-admin/post.php?post=123&action=edit
</pre>
            </div>
            
            <h3><?php echo esc_html__('Troubleshooting', 'alertyfast'); ?></h3>
            <ul>
                <li><?php echo esc_html__('Make sure your API key is entered correctly', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Ensure you have a valid subscription at AlertyFast', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Check that the WhatsApp number is formatted correctly (with country code)', 'alertyfast'); ?></li>
                <li><?php echo esc_html__('Verify that WooCommerce is active and functioning properly', 'alertyfast'); ?></li>
            </ul>
            
            <h3><?php echo esc_html__('Need Help?', 'alertyfast'); ?></h3>
            <p><?php echo esc_html__('For support, please contact', 'alertyfast'); ?> <a href="mailto:support@alertyfast.com">support@alertyfast.com</a></p>
        </div>
    </div>
    
    <style type="text/css">
        .tab-content {
            margin-top: 20px;
        }
    </style>
    
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            // Toggle phone field visibility based on checkbox state
            $('input[name="alertyfast_settings[new_order_notifications]"]').change(function() {
                if ($(this).is(':checked')) {
                    $('.new-order-phone-field').show();
                } else {
                    $('.new-order-phone-field').hide();
                }
            });
            
            $('input[name="alertyfast_settings[paid_order_notifications]"]').change(function() {
                if ($(this).is(':checked')) {
                    $('.paid-order-phone-field').show();
                } else {
                    $('.paid-order-phone-field').hide();
                }
            });
            
            // Test connection button
            $('#alertyfast_test_connection').click(function() {
                var apiKey = $('#alertyfast_api_key').val();
                var phoneNumber = $('#alertyfast_test_phone').val();
                var $button = $(this);
                var $result = $('#alertyfast_test_result');
                
                if (!apiKey) {
                    $result.html('<span style="color: red;"><?php echo esc_js(__('Please enter your API key.', 'alertyfast')); ?></span>');
                    return;
                }
                
                if (!phoneNumber) {
                    $result.html('<span style="color: red;"><?php echo esc_js(__('Please enter a phone number.', 'alertyfast')); ?></span>');
                    return;
                }
                
                $button.prop('disabled', true);
                $button.text('<?php echo esc_js(__('Sending...', 'alertyfast')); ?>');
                $result.html('<span style="color: blue;"><?php echo esc_js(__('Sending test message...', 'alertyfast')); ?></span>');
                
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'alertyfast_test_connection',
                        api_key: apiKey,
                        phone_number: phoneNumber,
                        nonce: '<?php echo wp_create_nonce('alertyfast_test_connection'); ?>'
                    },
                    success: function(response) {
                        if (response.success) {
                            $result.html('<span style="color: green;"><?php echo esc_js(__('Test message sent successfully!', 'alertyfast')); ?></span>');
                        } else {
                            $result.html('<span style="color: red;">' + response.data + '</span>');
                        }
                    },
                    error: function() {
                        $result.html('<span style="color: red;"><?php echo esc_js(__('An error occurred. Please try again.', 'alertyfast')); ?></span>');
                    },
                    complete: function() {
                        $button.prop('disabled', false);
                        $button.text('<?php echo esc_js(__('Send Test Message', 'alertyfast')); ?>');
                    }
                });
            });
            
            // Tab switching
            $('.nav-tab').click(function(e) {
                e.preventDefault();
                
                // Update active tab
                $('.nav-tab').removeClass('nav-tab-active');
                $(this).addClass('nav-tab-active');
                
                // Show selected tab content
                $('.tab-content').hide();
                
                if ($(this).attr('href') === '#help') {
                    $('#help-tab').show();
                } else {
                    $('#settings-tab').show();
                }
            });
        });
    </script>
    <?php
} 