<?php
/**
 * AlertyFast API Class
 * 
 * Handles API communication with the AlertyFast service
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class AlertyFast_API {
    /**
     * API endpoint URL
     *
     * @var string
     */
    private $api_url = 'https://alertyfast.com/api/send/whatsapp';

    /**
     * API key
     *
     * @var string
     */
    private $api_key;

    /**
     * Constructor
     */
    public function __construct() {
        $settings = new AlertyFast_Settings();
        $this->api_key = $settings->get_setting('api_key');
    }

    /**
     * Test API connection
     * 
     * @param string $phone_number The phone number to send test message to
     * @return array|WP_Error Response from the API or WP_Error on failure
     */
    public function test_connection($phone_number) {
        $test_message = __('This is a test message from AlertyFast WordPress plugin.', 'alertyfast');
        return $this->send_text_message($phone_number, $test_message);
    }

    /**
     * Send a text message via WhatsApp
     * 
     * @param string $phone_number The recipient's phone number
     * @param string $message The message content
     * @return array|WP_Error Response from the API or WP_Error on failure
     */
    public function send_text_message($phone_number, $message) {
        $payload = array(
            'content' => $message,
            'recipientAddress' => $phone_number,
            'channel' => 'WHATSAPP',
            'messageType' => 'TEXT'
        );

        return $this->send_request($payload);
    }

    /**
     * Send an image message via WhatsApp
     * 
     * @param string $phone_number The recipient's phone number
     * @param string $image_url The image URL
     * @param string $caption Optional caption for the image
     * @return array|WP_Error Response from the API or WP_Error on failure
     */
    public function send_image_message($phone_number, $image_url, $caption = '') {
        $payload = array(
            'content' => $image_url,
            'recipientAddress' => $phone_number,
            'channel' => 'WHATSAPP',
            'messageType' => 'IMAGE'
        );
        
        if (!empty($caption)) {
            $payload['caption'] = $caption;
        }

        return $this->send_request($payload);
    }

    /**
     * Send a request to the API
     * 
     * @param array $payload The request payload
     * @return array|WP_Error Response from the API or WP_Error on failure
     */
    private function send_request($payload) {
        // Check if API key is set
        if (empty($this->api_key)) {
            return new WP_Error('missing_api_key', __('AlertyFast API key is not set', 'alertyfast'));
        }

        $args = array(
            'method' => 'POST',
            'timeout' => 30,
            'redirection' => 5,
            'httpversion' => '1.1',
            'headers' => array(
                'Authorization' => 'Bearer ' . $this->api_key,
                'Content-Type' => 'application/json'
            ),
            'body' => wp_json_encode($payload),
            'cookies' => array()
        );

        $response = wp_remote_post($this->api_url, $args);

        if (is_wp_error($response)) {
            return $response;
        }

        $response_code = wp_remote_retrieve_response_code($response);
        $response_body = wp_remote_retrieve_body($response);
        $response_data = json_decode($response_body, true);

        if ($response_code >= 400) {
            return new WP_Error(
                'api_error',
                sprintf(__('API Error: %s', 'alertyfast'), isset($response_data['message']) ? $response_data['message'] : __('Unknown error', 'alertyfast')),
                array('status' => $response_code)
            );
        }

        return $response_data;
    }
} 