<?php
/**
 * AlertyFast WooCommerce Integration Class
 * 
 * Handles WooCommerce hooks and notifications
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class AlertyFast_WooCommerce {
    /**
     * Settings instance
     *
     * @var AlertyFast_Settings
     */
    private $settings;

    /**
     * API instance
     *
     * @var AlertyFast_API
     */
    private $api;

    /**
     * Constructor
     */
    public function __construct() {
        $this->settings = new AlertyFast_Settings();
        $this->api = new AlertyFast_API();

        // Register hooks only if WooCommerce is active
        if ($this->is_woocommerce_active()) {
            $this->register_hooks();
        }
    }

    /**
     * Check if WooCommerce is active
     * 
     * @return bool True if WooCommerce is active
     */
    private function is_woocommerce_active() {
        return in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')));
    }

    /**
     * Register WooCommerce hooks
     */
    private function register_hooks() {
        // New order notification
        if ($this->settings->get_setting('new_order_notifications') === 'yes') {
            add_action('woocommerce_new_order', array($this, 'new_order_notification'), 10, 1);
        }

        // Order status change to processing (payment received)
        if ($this->settings->get_setting('paid_order_notifications') === 'yes') {
            add_action('woocommerce_order_status_changed', array($this, 'order_status_changed'), 10, 3);
        }
    }

    /**
     * Send notification for new orders
     * 
     * @param int $order_id The order ID
     */
    public function new_order_notification($order_id) {
        // Get the phone number from settings
        $phone_number = $this->settings->get_setting('new_order_phone');
        
        if (empty($phone_number)) {
            $this->log_error('No phone number set for new order notifications.');
            return;
        }
        
        // Get the order
        $order = wc_get_order($order_id);
        
        if (!$order) {
            $this->log_error(sprintf('Order %s not found.', $order_id));
            return;
        }
        
        // Build the message
        $message = $this->build_new_order_message($order);
        
        // Send the message
        $response = $this->api->send_text_message($phone_number, $message);
        
        // Log the result
        if (is_wp_error($response)) {
            $this->log_error(sprintf('Error sending new order notification: %s', $response->get_error_message()));
        } else {
            $this->log_success(sprintf('New order notification sent successfully for order #%s.', $order_id));
        }
    }

    /**
     * Handle order status changes
     * 
     * @param int $order_id The order ID
     * @param string $old_status The old order status
     * @param string $new_status The new order status
     */
    public function order_status_changed($order_id, $old_status, $new_status) {
        // Only send notification if new status is 'processing' (payment received)
        if ($new_status !== 'processing') {
            return;
        }
        
        // Get the phone number from settings
        $phone_number = $this->settings->get_setting('paid_order_phone');
        
        if (empty($phone_number)) {
            $this->log_error('No phone number set for paid order notifications.');
            return;
        }
        
        // Get the order
        $order = wc_get_order($order_id);
        
        if (!$order) {
            $this->log_error(sprintf('Order %s not found.', $order_id));
            return;
        }
        
        // Build the message
        $message = $this->build_paid_order_message($order);
        
        // Send the message
        $response = $this->api->send_text_message($phone_number, $message);
        
        // Log the result
        if (is_wp_error($response)) {
            $this->log_error(sprintf('Error sending paid order notification: %s', $response->get_error_message()));
        } else {
            $this->log_success(sprintf('Paid order notification sent successfully for order #%s.', $order_id));
        }
    }
    
    /**
     * Build message for new order notification
     * 
     * @param WC_Order $order The order object
     * @return string The formatted message
     */
    private function build_new_order_message($order) {
        $message = sprintf(
            __("🛒 *New Order #%s*\n\n", 'alertyfast'),
            $order->get_order_number()
        );
        
        $message .= sprintf(
            __("Customer: %s %s\n", 'alertyfast'),
            $order->get_billing_first_name(),
            $order->get_billing_last_name()
        );
        
        // Get total amount without HTML tags
        $total = strip_tags(html_entity_decode($order->get_formatted_order_total()));
        
        $message .= sprintf(
            __("Total: %s\n", 'alertyfast'),
            $total
        );
        
        $message .= sprintf(
            __("Items: %d\n\n", 'alertyfast'),
            count($order->get_items())
        );
        
        // Add items
        $message .= __("*Order Items:*\n", 'alertyfast');
        foreach ($order->get_items() as $item) {
            // Get item price without HTML tags
            $price = strip_tags(html_entity_decode(wc_price($item->get_total())));
            
            $message .= sprintf(
                "• %s x%d - %s\n",
                $item->get_name(),
                $item->get_quantity(),
                $price
            );
        }
        
        $message .= "\n";
        $message .= sprintf(
            __("View Order: %s", 'alertyfast'),
            admin_url('post.php?post=' . $order->get_id() . '&action=edit')
        );
        
        return $message;
    }
    
    /**
     * Build message for paid order notification
     * 
     * @param WC_Order $order The order object
     * @return string The formatted message
     */
    private function build_paid_order_message($order) {
        $message = sprintf(
            __("💰 *Order #%s Paid*\n\n", 'alertyfast'),
            $order->get_order_number()
        );
        
        $message .= sprintf(
            __("Customer: %s %s\n", 'alertyfast'),
            $order->get_billing_first_name(),
            $order->get_billing_last_name()
        );
        
        // Get total amount without HTML tags
        $total = strip_tags(html_entity_decode($order->get_formatted_order_total()));
        
        $message .= sprintf(
            __("Total: %s\n", 'alertyfast'),
            $total
        );
        
        $message .= sprintf(
            __("Payment Method: %s\n\n", 'alertyfast'),
            $order->get_payment_method_title()
        );
        
        $message .= sprintf(
            __("View Order: %s", 'alertyfast'),
            admin_url('post.php?post=' . $order->get_id() . '&action=edit')
        );
        
        return $message;
    }
    
    /**
     * Log an error message
     * 
     * @param string $message The error message
     */
    private function log_error($message) {
        if (function_exists('wc_get_logger')) {
            wc_get_logger()->error($message, array('source' => 'alertyfast'));
        }
    }
    
    /**
     * Log a success message
     * 
     * @param string $message The success message
     */
    private function log_success($message) {
        if (function_exists('wc_get_logger')) {
            wc_get_logger()->info($message, array('source' => 'alertyfast'));
        }
    }
} 